"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .leader import Leader, LeaderTypedDict
from .projectlevel import ProjectLevel
from .projecttype import ProjectType
from datetime import datetime
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ProjectDetailTypedDict(TypedDict):
    r"""Detail schema for Project (used in single item endpoints)."""

    created_at: datetime
    key: str
    level: ProjectLevel
    r"""Enum for OWASP project levels."""
    name: str
    type: ProjectType
    r"""Enum for OWASP project types."""
    updated_at: datetime
    description: str
    leaders: List[LeaderTypedDict]


class ProjectDetail(BaseModel):
    r"""Detail schema for Project (used in single item endpoints)."""

    created_at: datetime

    key: str

    level: ProjectLevel
    r"""Enum for OWASP project levels."""

    name: str

    type: ProjectType
    r"""Enum for OWASP project types."""

    updated_at: datetime

    description: str

    leaders: List[Leader]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ProjectType(str, Enum):
    r"""Enum for OWASP project types."""

    CODE = "code"
    DOCUMENTATION = "documentation"
    OTHER = "other"
    TOOL = "tool"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from owasp_nest.models import NestError
from owasp_nest.types import BaseModel
from typing import Optional


class SnapshotErrorData(BaseModel):
    message: str


@dataclass(unsafe_hash=True)
class SnapshotError(NestError):
    r"""Snapshot error schema."""

    data: SnapshotErrorData = field(hash=False)

    def __init__(
        self,
        data: SnapshotErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class MemberTypedDict(TypedDict):
    r"""Schema for Member (minimal fields for list display)."""

    avatar_url: str
    created_at: datetime
    login: str
    name: str
    updated_at: datetime
    url: str


class Member(BaseModel):
    r"""Schema for Member (minimal fields for list display)."""

    avatar_url: str

    created_at: datetime

    login: str

    name: str

    updated_at: datetime

    url: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SnapshotTypedDict(TypedDict):
    r"""Schema for Snapshot (minimal fields for list display)."""

    created_at: datetime
    end_at: datetime
    key: str
    start_at: datetime
    title: str
    updated_at: datetime


class Snapshot(BaseModel):
    r"""Schema for Snapshot (minimal fields for list display)."""

    created_at: datetime

    end_at: datetime

    key: str

    start_at: datetime

    title: str

    updated_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SponsorTypedDict(TypedDict):
    r"""Schema for Sponsor (minimal fields for list display)."""

    image_url: str
    key: str
    name: str
    sponsor_type: str
    url: str


class Sponsor(BaseModel):
    r"""Schema for Sponsor (minimal fields for list display)."""

    image_url: str

    key: str

    name: str

    sponsor_type: str

    url: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IssueState(str, Enum):
    r"""Issue state choices."""

    OPEN = "open"
    CLOSED = "closed"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issuestate import IssueState
from datetime import datetime
from owasp_nest.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import TypedDict


class SnapshotIssueTypedDict(TypedDict):
    r"""Schema for Snapshot Issue (used in list endpoints)."""

    created_at: datetime
    state: IssueState
    r"""Issue state choices."""
    title: str
    updated_at: datetime
    url: str
    organization_login: Nullable[str]
    repository_name: Nullable[str]


class SnapshotIssue(BaseModel):
    r"""Schema for Snapshot Issue (used in list endpoints)."""

    created_at: datetime

    state: IssueState
    r"""Issue state choices."""

    title: str

    updated_at: datetime

    url: str

    organization_login: Nullable[str]

    repository_name: Nullable[str]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from owasp_nest import models, utils
from owasp_nest._hooks import HookContext
from owasp_nest.types import OptionalNullable, UNSET
from owasp_nest.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional


class Community(BaseSDK):
    def list_members(
        self,
        *,
        company: OptionalNullable[str] = UNSET,
        location: OptionalNullable[str] = UNSET,
        ordering: OptionalNullable[models.ListMembersOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedMember:
        r"""List members

        Retrieve a paginated list of OWASP community members.

        :param company: Company of the user
        :param location: Location of the member
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListMembersRequest(
            company=company,
            location=location,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/members/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_members",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedMember, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_members_async(
        self,
        *,
        company: OptionalNullable[str] = UNSET,
        location: OptionalNullable[str] = UNSET,
        ordering: OptionalNullable[models.ListMembersOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedMember:
        r"""List members

        Retrieve a paginated list of OWASP community members.

        :param company: Company of the user
        :param location: Location of the member
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListMembersRequest(
            company=company,
            location=location,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/members/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_members",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedMember, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def get_member(
        self,
        *,
        member_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MemberDetail:
        r"""Get member

        Retrieve member details.

        :param member_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetMemberRequest(
            member_id=member_id,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/members/{member_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_member",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.MemberDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.MemberErrorData, http_res)
            raise models.MemberError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def get_member_async(
        self,
        *,
        member_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MemberDetail:
        r"""Get member

        Retrieve member details.

        :param member_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetMemberRequest(
            member_id=member_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/members/{member_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_member",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.MemberDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.MemberErrorData, http_res)
            raise models.MemberError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def list_organizations(
        self,
        *,
        location: OptionalNullable[str] = UNSET,
        ordering: OptionalNullable[models.ListOrganizationsOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedOrganization:
        r"""List organizations

        Retrieve a paginated list of GitHub organizations.

        :param location: Location of the organization
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListOrganizationsRequest(
            location=location,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/organizations/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_organizations",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedOrganization, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_organizations_async(
        self,
        *,
        location: OptionalNullable[str] = UNSET,
        ordering: OptionalNullable[models.ListOrganizationsOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedOrganization:
        r"""List organizations

        Retrieve a paginated list of GitHub organizations.

        :param location: Location of the organization
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListOrganizationsRequest(
            location=location,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/organizations/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_organizations",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedOrganization, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def get_organization(
        self,
        *,
        organization_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.OrganizationDetail:
        r"""Get organization

        Retrieve project details.

        :param organization_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetOrganizationRequest(
            organization_id=organization_id,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/organizations/{organization_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_organization",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.OrganizationDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                models.OrganizationErrorData, http_res
            )
            raise models.OrganizationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def get_organization_async(
        self,
        *,
        organization_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.OrganizationDetail:
        r"""Get organization

        Retrieve project details.

        :param organization_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetOrganizationRequest(
            organization_id=organization_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/organizations/{organization_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_organization",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.OrganizationDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                models.OrganizationErrorData, http_res
            )
            raise models.OrganizationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def list_snapshots(
        self,
        *,
        ordering: OptionalNullable[models.ListSnapshotsOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedSnapshot:
        r"""List snapshots

        Retrieve a paginated list of OWASP snapshots.

        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotsRequest(
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/snapshots/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshots",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedSnapshot, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_snapshots_async(
        self,
        *,
        ordering: OptionalNullable[models.ListSnapshotsOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedSnapshot:
        r"""List snapshots

        Retrieve a paginated list of OWASP snapshots.

        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotsRequest(
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/snapshots/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshots",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedSnapshot, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def get_snapshot(
        self,
        *,
        snapshot_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SnapshotDetail:
        r"""Get snapshot

        Retrieve snapshot details.

        :param snapshot_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetSnapshotRequest(
            snapshot_id=snapshot_id,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_snapshot",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.SnapshotDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.SnapshotErrorData, http_res)
            raise models.SnapshotError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def get_snapshot_async(
        self,
        *,
        snapshot_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.SnapshotDetail:
        r"""Get snapshot

        Retrieve snapshot details.

        :param snapshot_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetSnapshotRequest(
            snapshot_id=snapshot_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_snapshot",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.SnapshotDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.SnapshotErrorData, http_res)
            raise models.SnapshotError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def list_snapshot_chapters(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotChaptersOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedChapter:
        r"""List new chapters in snapshot

        Retrieve a paginated list of new chapters in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotChaptersRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/chapters/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_chapters",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedChapter, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_snapshot_chapters_async(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotChaptersOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedChapter:
        r"""List new chapters in snapshot

        Retrieve a paginated list of new chapters in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotChaptersRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/chapters/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_chapters",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedChapter, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def list_snapshot_issues(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotIssuesOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedSnapshotIssue:
        r"""List new issues in snapshot

        Retrieve a paginated list of new issues in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotIssuesRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/issues/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_issues",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedSnapshotIssue, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_snapshot_issues_async(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotIssuesOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedSnapshotIssue:
        r"""List new issues in snapshot

        Retrieve a paginated list of new issues in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotIssuesRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/issues/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_issues",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedSnapshotIssue, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def list_snapshot_members(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotMembersOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedMember:
        r"""List new members in snapshot

        Retrieve a paginated list of new members in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotMembersRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/members/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_members",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedMember, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_snapshot_members_async(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotMembersOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedMember:
        r"""List new members in snapshot

        Retrieve a paginated list of new members in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotMembersRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/members/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_members",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedMember, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def list_snapshot_projects(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotProjectsOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedProject:
        r"""List new projects in snapshot

        Retrieve a paginated list of new projects in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotProjectsRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/projects/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_projects",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedProject, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_snapshot_projects_async(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotProjectsOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedProject:
        r"""List new projects in snapshot

        Retrieve a paginated list of new projects in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotProjectsRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/projects/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_projects",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedProject, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def list_snapshot_releases(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotReleasesOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedSnapshotRelease:
        r"""List new releases in snapshot

        Retrieve a paginated list of new releases in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotReleasesRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/releases/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_releases",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedSnapshotRelease, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_snapshot_releases_async(
        self,
        *,
        snapshot_id: str,
        ordering: OptionalNullable[models.ListSnapshotReleasesOrdering] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedSnapshotRelease:
        r"""List new releases in snapshot

        Retrieve a paginated list of new releases in a snapshot.

        :param snapshot_id:
        :param ordering: Ordering field
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListSnapshotReleasesRequest(
            snapshot_id=snapshot_id,
            ordering=ordering,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/snapshots/{snapshot_id}/releases/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_snapshot_releases",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedSnapshotRelease, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .milestone import Milestone, MilestoneTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedMilestoneTypedDict(TypedDict):
    current_page: int
    r"""Current page number"""
    has_next: bool
    r"""Whether there is a next page"""
    has_previous: bool
    r"""Whether there is a previous page"""
    items: List[MilestoneTypedDict]
    total_count: int
    r"""Total number of items"""
    total_pages: int
    r"""Total number of pages"""


class PagedMilestone(BaseModel):
    current_page: int
    r"""Current page number"""

    has_next: bool
    r"""Whether there is a next page"""

    has_previous: bool
    r"""Whether there is a previous page"""

    items: List[Milestone]

    total_count: int
    r"""Total number of items"""

    total_pages: int
    r"""Total number of pages"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SnapshotDetailTypedDict(TypedDict):
    r"""Detail schema for Snapshot (used in single item endpoints)."""

    created_at: datetime
    end_at: datetime
    key: str
    start_at: datetime
    title: str
    updated_at: datetime
    new_chapters_count: int
    new_issues_count: int
    new_projects_count: int
    new_releases_count: int
    new_users_count: int


class SnapshotDetail(BaseModel):
    r"""Detail schema for Snapshot (used in single item endpoints)."""

    created_at: datetime

    end_at: datetime

    key: str

    start_at: datetime

    title: str

    updated_at: datetime

    new_chapters_count: int

    new_issues_count: int

    new_projects_count: int

    new_releases_count: int

    new_users_count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issuestate import IssueState
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class IssueDetailTypedDict(TypedDict):
    r"""Detail schema for Issue (used in single item endpoints)."""

    created_at: datetime
    state: IssueState
    r"""Issue state choices."""
    title: str
    updated_at: datetime
    url: str
    body: str


class IssueDetail(BaseModel):
    r"""Detail schema for Issue (used in single item endpoints)."""

    created_at: datetime

    state: IssueState
    r"""Issue state choices."""

    title: str

    updated_at: datetime

    url: str

    body: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from owasp_nest.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from owasp_nest.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListCommitteesOrdering(str, Enum):
    r"""Ordering field"""

    CREATED_AT = "created_at"
    MINUS_CREATED_AT = "-created_at"
    UPDATED_AT = "updated_at"
    MINUS_UPDATED_AT = "-updated_at"


class ListCommitteesRequestTypedDict(TypedDict):
    ordering: NotRequired[Nullable[ListCommitteesOrdering]]
    r"""Ordering field"""
    page: NotRequired[int]
    r"""Page number"""
    page_size: NotRequired[int]
    r"""Number of items per page"""


class ListCommitteesRequest(BaseModel):
    ordering: Annotated[
        OptionalNullable[ListCommitteesOrdering],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Ordering field"""

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""Number of items per page"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["ordering", "page", "page_size"])
        nullable_fields = set(["ordering"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from importlib import import_module
import builtins
import sys


def dynamic_import(package, modname, retries=3):
    """Import a module relative to package, retrying on KeyError from half-initialized modules."""
    for attempt in range(retries):
        try:
            return import_module(modname, package)
        except KeyError:
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def lazy_getattr(attr_name, *, package, dynamic_imports, sub_packages=None):
    """Module-level __getattr__ that lazily loads from a dynamic_imports mapping.

    Args:
        attr_name: The attribute being looked up.
        package: The caller's __package__ (for relative imports).
        dynamic_imports: Dict mapping attribute names to relative module paths.
        sub_packages: Optional list of subpackage names to lazy-load.
    """
    module_name = dynamic_imports.get(attr_name)
    if module_name is not None:
        try:
            module = dynamic_import(package, module_name)
            return getattr(module, attr_name)
        except ImportError as e:
            raise ImportError(
                f"Failed to import {attr_name} from {module_name}: {e}"
            ) from e
        except AttributeError as e:
            raise AttributeError(
                f"Failed to get {attr_name} from {module_name}: {e}"
            ) from e

    if sub_packages and attr_name in sub_packages:
        return import_module(f".{attr_name}", package)

    raise AttributeError(f"module '{package}' has no attribute '{attr_name}'")


def lazy_dir(*, dynamic_imports, sub_packages=None):
    """Module-level __dir__ that lists lazily-loadable attributes."""
    lazy_attrs = builtins.list(dynamic_imports.keys())
    if sub_packages:
        lazy_attrs.extend(sub_packages)
    return builtins.sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ProjectLevel(str, Enum):
    r"""Enum for OWASP project levels."""

    OTHER = "other"
    INCUBATOR = "incubator"
    LAB = "lab"
    PRODUCTION = "production"
    FLAGSHIP = "flagship"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class SponsorDetailTypedDict(TypedDict):
    r"""Detail schema for Sponsor (used in single item endpoints)."""

    image_url: str
    key: str
    name: str
    sponsor_type: str
    url: str
    description: str
    is_member: bool
    job_url: str
    member_type: str


class SponsorDetail(BaseModel):
    r"""Detail schema for Sponsor (used in single item endpoints)."""

    image_url: str

    key: str

    name: str

    sponsor_type: str

    url: str

    description: str

    is_member: bool

    job_url: str

    member_type: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .nesterror import NestError
from typing import Any, TYPE_CHECKING

from owasp_nest.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .category import Category
    from .chapter import Chapter, ChapterTypedDict
    from .chapterdetail import ChapterDetail, ChapterDetailTypedDict
    from .chaptererror import ChapterError, ChapterErrorData
    from .committee import Committee, CommitteeTypedDict
    from .committeedetail import CommitteeDetail, CommitteeDetailTypedDict
    from .committeeerror import CommitteeError, CommitteeErrorData
    from .event import Event, EventTypedDict
    from .eventdetail import EventDetail, EventDetailTypedDict
    from .eventerror import EventError, EventErrorData
    from .get_chapterop import GetChapterRequest, GetChapterRequestTypedDict
    from .get_committeeop import GetCommitteeRequest, GetCommitteeRequestTypedDict
    from .get_eventop import GetEventRequest, GetEventRequestTypedDict
    from .get_issueop import GetIssueRequest, GetIssueRequestTypedDict
    from .get_memberop import GetMemberRequest, GetMemberRequestTypedDict
    from .get_milestoneop import GetMilestoneRequest, GetMilestoneRequestTypedDict
    from .get_organizationop import (
        GetOrganizationRequest,
        GetOrganizationRequestTypedDict,
    )
    from .get_projectop import GetProjectRequest, GetProjectRequestTypedDict
    from .get_releaseop import GetReleaseRequest, GetReleaseRequestTypedDict
    from .get_repositoryop import GetRepositoryRequest, GetRepositoryRequestTypedDict
    from .get_snapshotop import GetSnapshotRequest, GetSnapshotRequestTypedDict
    from .get_sponsorop import GetSponsorRequest, GetSponsorRequestTypedDict
    from .issue import Issue, IssueTypedDict
    from .issuedetail import IssueDetail, IssueDetailTypedDict
    from .issueerror import IssueError, IssueErrorData
    from .issuestate import IssueState
    from .leader import Leader, LeaderTypedDict
    from .list_chaptersop import (
        ListChaptersOrdering,
        ListChaptersRequest,
        ListChaptersRequestTypedDict,
    )
    from .list_committeesop import (
        ListCommitteesOrdering,
        ListCommitteesRequest,
        ListCommitteesRequestTypedDict,
    )
    from .list_eventsop import (
        ListEventsOrdering,
        ListEventsRequest,
        ListEventsRequestTypedDict,
    )
    from .list_issuesop import (
        ListIssuesOrdering,
        ListIssuesRequest,
        ListIssuesRequestTypedDict,
    )
    from .list_membersop import (
        ListMembersOrdering,
        ListMembersRequest,
        ListMembersRequestTypedDict,
    )
    from .list_milestonesop import (
        ListMilestonesOrdering,
        ListMilestonesRequest,
        ListMilestonesRequestTypedDict,
    )
    from .list_organizationsop import (
        ListOrganizationsOrdering,
        ListOrganizationsRequest,
        ListOrganizationsRequestTypedDict,
    )
    from .list_projectsop import (
        ListProjectsOrdering,
        ListProjectsRequest,
        ListProjectsRequestTypedDict,
    )
    from .list_releasesop import (
        ListReleasesOrdering,
        ListReleasesRequest,
        ListReleasesRequestTypedDict,
    )
    from .list_repositoriesop import (
        ListRepositoriesOrdering,
        ListRepositoriesRequest,
        ListRepositoriesRequestTypedDict,
    )
    from .list_snapshot_chaptersop import (
        ListSnapshotChaptersOrdering,
        ListSnapshotChaptersRequest,
        ListSnapshotChaptersRequestTypedDict,
    )
    from .list_snapshot_issuesop import (
        ListSnapshotIssuesOrdering,
        ListSnapshotIssuesRequest,
        ListSnapshotIssuesRequestTypedDict,
    )
    from .list_snapshot_membersop import (
        ListSnapshotMembersOrdering,
        ListSnapshotMembersRequest,
        ListSnapshotMembersRequestTypedDict,
    )
    from .list_snapshot_projectsop import (
        ListSnapshotProjectsOrdering,
        ListSnapshotProjectsRequest,
        ListSnapshotProjectsRequestTypedDict,
    )
    from .list_snapshot_releasesop import (
        ListSnapshotReleasesOrdering,
        ListSnapshotReleasesRequest,
        ListSnapshotReleasesRequestTypedDict,
    )
    from .list_snapshotsop import (
        ListSnapshotsOrdering,
        ListSnapshotsRequest,
        ListSnapshotsRequestTypedDict,
    )
    from .list_sponsorsop import (
        ListSponsorsOrdering,
        ListSponsorsRequest,
        ListSponsorsRequestTypedDict,
    )
    from .member import Member, MemberTypedDict
    from .memberdetail import MemberDetail, MemberDetailTypedDict
    from .membererror import MemberError, MemberErrorData
    from .membertype import MemberType
    from .milestone import Milestone, MilestoneTypedDict
    from .milestonedetail import MilestoneDetail, MilestoneDetailTypedDict
    from .milestoneerror import MilestoneError, MilestoneErrorData
    from .nestapierror import NestAPIError
    from .no_response_error import NoResponseError
    from .organization import Organization, OrganizationTypedDict
    from .organizationdetail import OrganizationDetail, OrganizationDetailTypedDict
    from .organizationerror import OrganizationError, OrganizationErrorData
    from .pagedchapter import PagedChapter, PagedChapterTypedDict
    from .pagedcommittee import PagedCommittee, PagedCommitteeTypedDict
    from .pagedevent import PagedEvent, PagedEventTypedDict
    from .pagedissue import PagedIssue, PagedIssueTypedDict
    from .pagedmember import PagedMember, PagedMemberTypedDict
    from .pagedmilestone import PagedMilestone, PagedMilestoneTypedDict
    from .pagedorganization import PagedOrganization, PagedOrganizationTypedDict
    from .pagedproject import PagedProject, PagedProjectTypedDict
    from .pagedrelease import PagedRelease, PagedReleaseTypedDict
    from .pagedrepository import PagedRepository, PagedRepositoryTypedDict
    from .pagedsnapshot import PagedSnapshot, PagedSnapshotTypedDict
    from .pagedsnapshotissue import PagedSnapshotIssue, PagedSnapshotIssueTypedDict
    from .pagedsnapshotrelease import (
        PagedSnapshotRelease,
        PagedSnapshotReleaseTypedDict,
    )
    from .pagedsponsor import PagedSponsor, PagedSponsorTypedDict
    from .project import Project, ProjectTypedDict
    from .projectdetail import ProjectDetail, ProjectDetailTypedDict
    from .projecterror import ProjectError, ProjectErrorData
    from .projectlevel import ProjectLevel
    from .projecttype import ProjectType
    from .release import Release, ReleaseTypedDict
    from .releasedetail import ReleaseDetail, ReleaseDetailTypedDict
    from .releaseerror import ReleaseError, ReleaseErrorData
    from .repository import Repository, RepositoryTypedDict
    from .repositorydetail import RepositoryDetail, RepositoryDetailTypedDict
    from .repositoryerror import RepositoryError, RepositoryErrorData
    from .responsevalidationerror import ResponseValidationError
    from .security import Security, SecurityTypedDict
    from .snapshot import Snapshot, SnapshotTypedDict
    from .snapshotdetail import SnapshotDetail, SnapshotDetailTypedDict
    from .snapshoterror import SnapshotError, SnapshotErrorData
    from .snapshotissue import SnapshotIssue, SnapshotIssueTypedDict
    from .snapshotrelease import SnapshotRelease, SnapshotReleaseTypedDict
    from .sponsor import Sponsor, SponsorTypedDict
    from .sponsordetail import SponsorDetail, SponsorDetailTypedDict
    from .sponsorerror import SponsorError, SponsorErrorData
    from .validationerrorschema import (
        Errors,
        ErrorsTypedDict,
        ValidationErrorSchema,
        ValidationErrorSchemaData,
    )

__all__ = [
    "Category",
    "Chapter",
    "ChapterDetail",
    "ChapterDetailTypedDict",
    "ChapterError",
    "ChapterErrorData",
    "ChapterTypedDict",
    "Committee",
    "CommitteeDetail",
    "CommitteeDetailTypedDict",
    "CommitteeError",
    "CommitteeErrorData",
    "CommitteeTypedDict",
    "Errors",
    "ErrorsTypedDict",
    "Event",
    "EventDetail",
    "EventDetailTypedDict",
    "EventError",
    "EventErrorData",
    "EventTypedDict",
    "GetChapterRequest",
    "GetChapterRequestTypedDict",
    "GetCommitteeRequest",
    "GetCommitteeRequestTypedDict",
    "GetEventRequest",
    "GetEventRequestTypedDict",
    "GetIssueRequest",
    "GetIssueRequestTypedDict",
    "GetMemberRequest",
    "GetMemberRequestTypedDict",
    "GetMilestoneRequest",
    "GetMilestoneRequestTypedDict",
    "GetOrganizationRequest",
    "GetOrganizationRequestTypedDict",
    "GetProjectRequest",
    "GetProjectRequestTypedDict",
    "GetReleaseRequest",
    "GetReleaseRequestTypedDict",
    "GetRepositoryRequest",
    "GetRepositoryRequestTypedDict",
    "GetSnapshotRequest",
    "GetSnapshotRequestTypedDict",
    "GetSponsorRequest",
    "GetSponsorRequestTypedDict",
    "Issue",
    "IssueDetail",
    "IssueDetailTypedDict",
    "IssueError",
    "IssueErrorData",
    "IssueState",
    "IssueTypedDict",
    "Leader",
    "LeaderTypedDict",
    "ListChaptersOrdering",
    "ListChaptersRequest",
    "ListChaptersRequestTypedDict",
    "ListCommitteesOrdering",
    "ListCommitteesRequest",
    "ListCommitteesRequestTypedDict",
    "ListEventsOrdering",
    "ListEventsRequest",
    "ListEventsRequestTypedDict",
    "ListIssuesOrdering",
    "ListIssuesRequest",
    "ListIssuesRequestTypedDict",
    "ListMembersOrdering",
    "ListMembersRequest",
    "ListMembersRequestTypedDict",
    "ListMilestonesOrdering",
    "ListMilestonesRequest",
    "ListMilestonesRequestTypedDict",
    "ListOrganizationsOrdering",
    "ListOrganizationsRequest",
    "ListOrganizationsRequestTypedDict",
    "ListProjectsOrdering",
    "ListProjectsRequest",
    "ListProjectsRequestTypedDict",
    "ListReleasesOrdering",
    "ListReleasesRequest",
    "ListReleasesRequestTypedDict",
    "ListRepositoriesOrdering",
    "ListRepositoriesRequest",
    "ListRepositoriesRequestTypedDict",
    "ListSnapshotChaptersOrdering",
    "ListSnapshotChaptersRequest",
    "ListSnapshotChaptersRequestTypedDict",
    "ListSnapshotIssuesOrdering",
    "ListSnapshotIssuesRequest",
    "ListSnapshotIssuesRequestTypedDict",
    "ListSnapshotMembersOrdering",
    "ListSnapshotMembersRequest",
    "ListSnapshotMembersRequestTypedDict",
    "ListSnapshotProjectsOrdering",
    "ListSnapshotProjectsRequest",
    "ListSnapshotProjectsRequestTypedDict",
    "ListSnapshotReleasesOrdering",
    "ListSnapshotReleasesRequest",
    "ListSnapshotReleasesRequestTypedDict",
    "ListSnapshotsOrdering",
    "ListSnapshotsRequest",
    "ListSnapshotsRequestTypedDict",
    "ListSponsorsOrdering",
    "ListSponsorsRequest",
    "ListSponsorsRequestTypedDict",
    "Member",
    "MemberDetail",
    "MemberDetailTypedDict",
    "MemberError",
    "MemberErrorData",
    "MemberType",
    "MemberTypedDict",
    "Milestone",
    "MilestoneDetail",
    "MilestoneDetailTypedDict",
    "MilestoneError",
    "MilestoneErrorData",
    "MilestoneTypedDict",
    "NestAPIError",
    "NestError",
    "NoResponseError",
    "Organization",
    "OrganizationDetail",
    "OrganizationDetailTypedDict",
    "OrganizationError",
    "OrganizationErrorData",
    "OrganizationTypedDict",
    "PagedChapter",
    "PagedChapterTypedDict",
    "PagedCommittee",
    "PagedCommitteeTypedDict",
    "PagedEvent",
    "PagedEventTypedDict",
    "PagedIssue",
    "PagedIssueTypedDict",
    "PagedMember",
    "PagedMemberTypedDict",
    "PagedMilestone",
    "PagedMilestoneTypedDict",
    "PagedOrganization",
    "PagedOrganizationTypedDict",
    "PagedProject",
    "PagedProjectTypedDict",
    "PagedRelease",
    "PagedReleaseTypedDict",
    "PagedRepository",
    "PagedRepositoryTypedDict",
    "PagedSnapshot",
    "PagedSnapshotIssue",
    "PagedSnapshotIssueTypedDict",
    "PagedSnapshotRelease",
    "PagedSnapshotReleaseTypedDict",
    "PagedSnapshotTypedDict",
    "PagedSponsor",
    "PagedSponsorTypedDict",
    "Project",
    "ProjectDetail",
    "ProjectDetailTypedDict",
    "ProjectError",
    "ProjectErrorData",
    "ProjectLevel",
    "ProjectType",
    "ProjectTypedDict",
    "Release",
    "ReleaseDetail",
    "ReleaseDetailTypedDict",
    "ReleaseError",
    "ReleaseErrorData",
    "ReleaseTypedDict",
    "Repository",
    "RepositoryDetail",
    "RepositoryDetailTypedDict",
    "RepositoryError",
    "RepositoryErrorData",
    "RepositoryTypedDict",
    "ResponseValidationError",
    "Security",
    "SecurityTypedDict",
    "Snapshot",
    "SnapshotDetail",
    "SnapshotDetailTypedDict",
    "SnapshotError",
    "SnapshotErrorData",
    "SnapshotIssue",
    "SnapshotIssueTypedDict",
    "SnapshotRelease",
    "SnapshotReleaseTypedDict",
    "SnapshotTypedDict",
    "Sponsor",
    "SponsorDetail",
    "SponsorDetailTypedDict",
    "SponsorError",
    "SponsorErrorData",
    "SponsorTypedDict",
    "ValidationErrorSchema",
    "ValidationErrorSchemaData",
]

_dynamic_imports: dict[str, str] = {
    "Category": ".category",
    "Chapter": ".chapter",
    "ChapterTypedDict": ".chapter",
    "ChapterDetail": ".chapterdetail",
    "ChapterDetailTypedDict": ".chapterdetail",
    "ChapterError": ".chaptererror",
    "ChapterErrorData": ".chaptererror",
    "Committee": ".committee",
    "CommitteeTypedDict": ".committee",
    "CommitteeDetail": ".committeedetail",
    "CommitteeDetailTypedDict": ".committeedetail",
    "CommitteeError": ".committeeerror",
    "CommitteeErrorData": ".committeeerror",
    "Event": ".event",
    "EventTypedDict": ".event",
    "EventDetail": ".eventdetail",
    "EventDetailTypedDict": ".eventdetail",
    "EventError": ".eventerror",
    "EventErrorData": ".eventerror",
    "GetChapterRequest": ".get_chapterop",
    "GetChapterRequestTypedDict": ".get_chapterop",
    "GetCommitteeRequest": ".get_committeeop",
    "GetCommitteeRequestTypedDict": ".get_committeeop",
    "GetEventRequest": ".get_eventop",
    "GetEventRequestTypedDict": ".get_eventop",
    "GetIssueRequest": ".get_issueop",
    "GetIssueRequestTypedDict": ".get_issueop",
    "GetMemberRequest": ".get_memberop",
    "GetMemberRequestTypedDict": ".get_memberop",
    "GetMilestoneRequest": ".get_milestoneop",
    "GetMilestoneRequestTypedDict": ".get_milestoneop",
    "GetOrganizationRequest": ".get_organizationop",
    "GetOrganizationRequestTypedDict": ".get_organizationop",
    "GetProjectRequest": ".get_projectop",
    "GetProjectRequestTypedDict": ".get_projectop",
    "GetReleaseRequest": ".get_releaseop",
    "GetReleaseRequestTypedDict": ".get_releaseop",
    "GetRepositoryRequest": ".get_repositoryop",
    "GetRepositoryRequestTypedDict": ".get_repositoryop",
    "GetSnapshotRequest": ".get_snapshotop",
    "GetSnapshotRequestTypedDict": ".get_snapshotop",
    "GetSponsorRequest": ".get_sponsorop",
    "GetSponsorRequestTypedDict": ".get_sponsorop",
    "Issue": ".issue",
    "IssueTypedDict": ".issue",
    "IssueDetail": ".issuedetail",
    "IssueDetailTypedDict": ".issuedetail",
    "IssueError": ".issueerror",
    "IssueErrorData": ".issueerror",
    "IssueState": ".issuestate",
    "Leader": ".leader",
    "LeaderTypedDict": ".leader",
    "ListChaptersOrdering": ".list_chaptersop",
    "ListChaptersRequest": ".list_chaptersop",
    "ListChaptersRequestTypedDict": ".list_chaptersop",
    "ListCommitteesOrdering": ".list_committeesop",
    "ListCommitteesRequest": ".list_committeesop",
    "ListCommitteesRequestTypedDict": ".list_committeesop",
    "ListEventsOrdering": ".list_eventsop",
    "ListEventsRequest": ".list_eventsop",
    "ListEventsRequestTypedDict": ".list_eventsop",
    "ListIssuesOrdering": ".list_issuesop",
    "ListIssuesRequest": ".list_issuesop",
    "ListIssuesRequestTypedDict": ".list_issuesop",
    "ListMembersOrdering": ".list_membersop",
    "ListMembersRequest": ".list_membersop",
    "ListMembersRequestTypedDict": ".list_membersop",
    "ListMilestonesOrdering": ".list_milestonesop",
    "ListMilestonesRequest": ".list_milestonesop",
    "ListMilestonesRequestTypedDict": ".list_milestonesop",
    "ListOrganizationsOrdering": ".list_organizationsop",
    "ListOrganizationsRequest": ".list_organizationsop",
    "ListOrganizationsRequestTypedDict": ".list_organizationsop",
    "ListProjectsOrdering": ".list_projectsop",
    "ListProjectsRequest": ".list_projectsop",
    "ListProjectsRequestTypedDict": ".list_projectsop",
    "ListReleasesOrdering": ".list_releasesop",
    "ListReleasesRequest": ".list_releasesop",
    "ListReleasesRequestTypedDict": ".list_releasesop",
    "ListRepositoriesOrdering": ".list_repositoriesop",
    "ListRepositoriesRequest": ".list_repositoriesop",
    "ListRepositoriesRequestTypedDict": ".list_repositoriesop",
    "ListSnapshotChaptersOrdering": ".list_snapshot_chaptersop",
    "ListSnapshotChaptersRequest": ".list_snapshot_chaptersop",
    "ListSnapshotChaptersRequestTypedDict": ".list_snapshot_chaptersop",
    "ListSnapshotIssuesOrdering": ".list_snapshot_issuesop",
    "ListSnapshotIssuesRequest": ".list_snapshot_issuesop",
    "ListSnapshotIssuesRequestTypedDict": ".list_snapshot_issuesop",
    "ListSnapshotMembersOrdering": ".list_snapshot_membersop",
    "ListSnapshotMembersRequest": ".list_snapshot_membersop",
    "ListSnapshotMembersRequestTypedDict": ".list_snapshot_membersop",
    "ListSnapshotProjectsOrdering": ".list_snapshot_projectsop",
    "ListSnapshotProjectsRequest": ".list_snapshot_projectsop",
    "ListSnapshotProjectsRequestTypedDict": ".list_snapshot_projectsop",
    "ListSnapshotReleasesOrdering": ".list_snapshot_releasesop",
    "ListSnapshotReleasesRequest": ".list_snapshot_releasesop",
    "ListSnapshotReleasesRequestTypedDict": ".list_snapshot_releasesop",
    "ListSnapshotsOrdering": ".list_snapshotsop",
    "ListSnapshotsRequest": ".list_snapshotsop",
    "ListSnapshotsRequestTypedDict": ".list_snapshotsop",
    "ListSponsorsOrdering": ".list_sponsorsop",
    "ListSponsorsRequest": ".list_sponsorsop",
    "ListSponsorsRequestTypedDict": ".list_sponsorsop",
    "Member": ".member",
    "MemberTypedDict": ".member",
    "MemberDetail": ".memberdetail",
    "MemberDetailTypedDict": ".memberdetail",
    "MemberError": ".membererror",
    "MemberErrorData": ".membererror",
    "MemberType": ".membertype",
    "Milestone": ".milestone",
    "MilestoneTypedDict": ".milestone",
    "MilestoneDetail": ".milestonedetail",
    "MilestoneDetailTypedDict": ".milestonedetail",
    "MilestoneError": ".milestoneerror",
    "MilestoneErrorData": ".milestoneerror",
    "NestAPIError": ".nestapierror",
    "NoResponseError": ".no_response_error",
    "Organization": ".organization",
    "OrganizationTypedDict": ".organization",
    "OrganizationDetail": ".organizationdetail",
    "OrganizationDetailTypedDict": ".organizationdetail",
    "OrganizationError": ".organizationerror",
    "OrganizationErrorData": ".organizationerror",
    "PagedChapter": ".pagedchapter",
    "PagedChapterTypedDict": ".pagedchapter",
    "PagedCommittee": ".pagedcommittee",
    "PagedCommitteeTypedDict": ".pagedcommittee",
    "PagedEvent": ".pagedevent",
    "PagedEventTypedDict": ".pagedevent",
    "PagedIssue": ".pagedissue",
    "PagedIssueTypedDict": ".pagedissue",
    "PagedMember": ".pagedmember",
    "PagedMemberTypedDict": ".pagedmember",
    "PagedMilestone": ".pagedmilestone",
    "PagedMilestoneTypedDict": ".pagedmilestone",
    "PagedOrganization": ".pagedorganization",
    "PagedOrganizationTypedDict": ".pagedorganization",
    "PagedProject": ".pagedproject",
    "PagedProjectTypedDict": ".pagedproject",
    "PagedRelease": ".pagedrelease",
    "PagedReleaseTypedDict": ".pagedrelease",
    "PagedRepository": ".pagedrepository",
    "PagedRepositoryTypedDict": ".pagedrepository",
    "PagedSnapshot": ".pagedsnapshot",
    "PagedSnapshotTypedDict": ".pagedsnapshot",
    "PagedSnapshotIssue": ".pagedsnapshotissue",
    "PagedSnapshotIssueTypedDict": ".pagedsnapshotissue",
    "PagedSnapshotRelease": ".pagedsnapshotrelease",
    "PagedSnapshotReleaseTypedDict": ".pagedsnapshotrelease",
    "PagedSponsor": ".pagedsponsor",
    "PagedSponsorTypedDict": ".pagedsponsor",
    "Project": ".project",
    "ProjectTypedDict": ".project",
    "ProjectDetail": ".projectdetail",
    "ProjectDetailTypedDict": ".projectdetail",
    "ProjectError": ".projecterror",
    "ProjectErrorData": ".projecterror",
    "ProjectLevel": ".projectlevel",
    "ProjectType": ".projecttype",
    "Release": ".release",
    "ReleaseTypedDict": ".release",
    "ReleaseDetail": ".releasedetail",
    "ReleaseDetailTypedDict": ".releasedetail",
    "ReleaseError": ".releaseerror",
    "ReleaseErrorData": ".releaseerror",
    "Repository": ".repository",
    "RepositoryTypedDict": ".repository",
    "RepositoryDetail": ".repositorydetail",
    "RepositoryDetailTypedDict": ".repositorydetail",
    "RepositoryError": ".repositoryerror",
    "RepositoryErrorData": ".repositoryerror",
    "ResponseValidationError": ".responsevalidationerror",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "Snapshot": ".snapshot",
    "SnapshotTypedDict": ".snapshot",
    "SnapshotDetail": ".snapshotdetail",
    "SnapshotDetailTypedDict": ".snapshotdetail",
    "SnapshotError": ".snapshoterror",
    "SnapshotErrorData": ".snapshoterror",
    "SnapshotIssue": ".snapshotissue",
    "SnapshotIssueTypedDict": ".snapshotissue",
    "SnapshotRelease": ".snapshotrelease",
    "SnapshotReleaseTypedDict": ".snapshotrelease",
    "Sponsor": ".sponsor",
    "SponsorTypedDict": ".sponsor",
    "SponsorDetail": ".sponsordetail",
    "SponsorDetailTypedDict": ".sponsordetail",
    "SponsorError": ".sponsorerror",
    "SponsorErrorData": ".sponsorerror",
    "Errors": ".validationerrorschema",
    "ErrorsTypedDict": ".validationerrorschema",
    "ValidationErrorSchema": ".validationerrorschema",
    "ValidationErrorSchemaData": ".validationerrorschema",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class MemberDetailTypedDict(TypedDict):
    r"""Detail schema for Member (used in single item endpoints)."""

    avatar_url: str
    created_at: datetime
    login: str
    name: str
    updated_at: datetime
    url: str
    bio: str
    company: str
    followers_count: int
    following_count: int
    location: str
    public_repositories_count: int
    title: str
    twitter_username: str


class MemberDetail(BaseModel):
    r"""Detail schema for Member (used in single item endpoints)."""

    avatar_url: str

    created_at: datetime

    login: str

    name: str

    updated_at: datetime

    url: str

    bio: str

    company: str

    followers_count: int

    following_count: int

    location: str

    public_repositories_count: int

    title: str

    twitter_username: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "owasp-nest"
__version__: str = "0.4.1"
__openapi_doc_version__: str = "0.3.6"
__gen_version__: str = "2.852.1"
__user_agent__: str = "speakeasy-sdk/python 0.4.1 2.852.1 0.3.6 owasp-nest"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issuestate import IssueState
from enum import Enum
from owasp_nest.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from owasp_nest.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListMilestonesOrdering(str, Enum):
    CREATED_AT = "created_at"
    MINUS_CREATED_AT = "-created_at"
    UPDATED_AT = "updated_at"
    MINUS_UPDATED_AT = "-updated_at"


class ListMilestonesRequestTypedDict(TypedDict):
    organization: NotRequired[Nullable[str]]
    r"""Organization that milestones belong to (filtered by repository owner)"""
    repository: NotRequired[Nullable[str]]
    r"""Repository that milestones belong to"""
    state: NotRequired[Nullable[IssueState]]
    r"""Milestone state"""
    ordering: NotRequired[Nullable[ListMilestonesOrdering]]
    page: NotRequired[int]
    r"""Page number"""
    page_size: NotRequired[int]
    r"""Number of items per page"""


class ListMilestonesRequest(BaseModel):
    organization: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Organization that milestones belong to (filtered by repository owner)"""

    repository: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Repository that milestones belong to"""

    state: Annotated[
        OptionalNullable[IssueState],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Milestone state"""

    ordering: Annotated[
        OptionalNullable[ListMilestonesOrdering],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""Number of items per page"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["organization", "repository", "state", "ordering", "page", "page_size"]
        )
        nullable_fields = set(["organization", "repository", "state", "ordering"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from owasp_nest.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from owasp_nest.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListChaptersOrdering(str, Enum):
    r"""Ordering field"""

    CREATED_AT = "created_at"
    MINUS_CREATED_AT = "-created_at"
    UPDATED_AT = "updated_at"
    MINUS_UPDATED_AT = "-updated_at"
    LATITUDE = "latitude"
    MINUS_LATITUDE = "-latitude"
    LONGITUDE = "longitude"
    MINUS_LONGITUDE = "-longitude"


class ListChaptersRequestTypedDict(TypedDict):
    latitude_gte: NotRequired[Nullable[float]]
    r"""Latitude greater than or equal to"""
    latitude_lte: NotRequired[Nullable[float]]
    r"""Latitude less than or equal to"""
    longitude_gte: NotRequired[Nullable[float]]
    r"""Longitude greater than or equal to"""
    longitude_lte: NotRequired[Nullable[float]]
    r"""Longitude less than or equal to"""
    country: NotRequired[Nullable[str]]
    r"""Country of the chapter"""
    ordering: NotRequired[Nullable[ListChaptersOrdering]]
    r"""Ordering field"""
    page: NotRequired[int]
    r"""Page number"""
    page_size: NotRequired[int]
    r"""Number of items per page"""


class ListChaptersRequest(BaseModel):
    latitude_gte: Annotated[
        OptionalNullable[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Latitude greater than or equal to"""

    latitude_lte: Annotated[
        OptionalNullable[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Latitude less than or equal to"""

    longitude_gte: Annotated[
        OptionalNullable[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Longitude greater than or equal to"""

    longitude_lte: Annotated[
        OptionalNullable[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Longitude less than or equal to"""

    country: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Country of the chapter"""

    ordering: Annotated[
        OptionalNullable[ListChaptersOrdering],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Ordering field"""

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""Number of items per page"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "latitude_gte",
                "latitude_lte",
                "longitude_gte",
                "longitude_lte",
                "country",
                "ordering",
                "page",
                "page_size",
            ]
        )
        nullable_fields = set(
            [
                "latitude_gte",
                "latitude_lte",
                "longitude_gte",
                "longitude_lte",
                "country",
                "ordering",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from owasp_nest import models, utils
from owasp_nest._hooks import HookContext
from owasp_nest.types import OptionalNullable, UNSET
from owasp_nest.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class Events(BaseSDK):
    def list_events(
        self,
        *,
        latitude_gte: OptionalNullable[float] = UNSET,
        latitude_lte: OptionalNullable[float] = UNSET,
        longitude_gte: OptionalNullable[float] = UNSET,
        longitude_lte: OptionalNullable[float] = UNSET,
        category: OptionalNullable[List[models.Category]] = UNSET,
        ordering: OptionalNullable[models.ListEventsOrdering] = UNSET,
        is_upcoming: OptionalNullable[bool] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedEvent:
        r"""List events

        Retrieve a paginated list of OWASP events.

        :param latitude_gte: Latitude greater than or equal to
        :param latitude_lte: Latitude less than or equal to
        :param longitude_gte: Longitude greater than or equal to
        :param longitude_lte: Longitude less than or equal to
        :param category: Filter events by category
        :param ordering: Ordering field
        :param is_upcoming: Filter for upcoming events
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListEventsRequest(
            latitude_gte=latitude_gte,
            latitude_lte=latitude_lte,
            longitude_gte=longitude_gte,
            longitude_lte=longitude_lte,
            category=category,
            ordering=ordering,
            is_upcoming=is_upcoming,
            page=page,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/events/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_events",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedEvent, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def list_events_async(
        self,
        *,
        latitude_gte: OptionalNullable[float] = UNSET,
        latitude_lte: OptionalNullable[float] = UNSET,
        longitude_gte: OptionalNullable[float] = UNSET,
        longitude_lte: OptionalNullable[float] = UNSET,
        category: OptionalNullable[List[models.Category]] = UNSET,
        ordering: OptionalNullable[models.ListEventsOrdering] = UNSET,
        is_upcoming: OptionalNullable[bool] = UNSET,
        page: Optional[int] = 1,
        page_size: Optional[int] = 100,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PagedEvent:
        r"""List events

        Retrieve a paginated list of OWASP events.

        :param latitude_gte: Latitude greater than or equal to
        :param latitude_lte: Latitude less than or equal to
        :param longitude_gte: Longitude greater than or equal to
        :param longitude_lte: Longitude less than or equal to
        :param category: Filter events by category
        :param ordering: Ordering field
        :param is_upcoming: Filter for upcoming events
        :param page: Page number
        :param page_size: Number of items per page
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListEventsRequest(
            latitude_gte=latitude_gte,
            latitude_lte=latitude_lte,
            longitude_gte=longitude_gte,
            longitude_lte=longitude_lte,
            category=category,
            ordering=ordering,
            is_upcoming=is_upcoming,
            page=page,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/events/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="list_events",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PagedEvent, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    def get_event(
        self,
        *,
        event_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EventDetail:
        r"""Get event

        Retrieve an event details.

        :param event_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetEventRequest(
            event_id=event_id,
        )

        req = self._build_request(
            method="GET",
            path="/api/v0/events/{event_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_event",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EventDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.EventErrorData, http_res)
            raise models.EventError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)

    async def get_event_async(
        self,
        *,
        event_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EventDetail:
        r"""Get event

        Retrieve an event details.

        :param event_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetEventRequest(
            event_id=event_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v0/events/{event_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_event",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EventDetail, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                models.ValidationErrorSchemaData, http_res
            )
            raise models.ValidationErrorSchema(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(models.EventErrorData, http_res)
            raise models.EventError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.NestAPIError("API error occurred", http_res, http_res_text)

        raise models.NestAPIError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from pydantic import ConfigDict, model_serializer
from pydantic import BaseModel as PydanticBaseModel
from pydantic_core import core_schema
from typing import TYPE_CHECKING, Any, Literal, Optional, TypeVar, Union
from typing_extensions import TypeAliasType, TypeAlias


class BaseModel(PydanticBaseModel):
    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, protected_namespaces=()
    )


class Unset(BaseModel):
    @model_serializer(mode="plain")
    def serialize_model(self):
        return UNSET_SENTINEL

    def __bool__(self) -> Literal[False]:
        return False


UNSET = Unset()
UNSET_SENTINEL = "~?~unset~?~sentinel~?~"


T = TypeVar("T")
if TYPE_CHECKING:
    Nullable: TypeAlias = Union[T, None]
    OptionalNullable: TypeAlias = Union[Optional[Nullable[T]], Unset]
else:
    Nullable = TypeAliasType("Nullable", Union[T, None], type_params=(T,))
    OptionalNullable = TypeAliasType(
        "OptionalNullable", Union[Optional[Nullable[T]], Unset], type_params=(T,)
    )


class UnrecognizedStr(str):
    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type: Any, _handler: Any) -> core_schema.CoreSchema:
        # Make UnrecognizedStr only work in lax mode, not strict mode
        # This makes it a "fallback" option when more specific types (like Literals) don't match
        def validate_lax(v: Any) -> 'UnrecognizedStr':
            if isinstance(v, cls):
                return v
            return cls(str(v))

        # Use lax_or_strict_schema where strict always fails
        # This forces Pydantic to prefer other union members in strict mode
        # and only fall back to UnrecognizedStr in lax mode
        return core_schema.lax_or_strict_schema(
            lax_schema=core_schema.chain_schema([
                core_schema.str_schema(),
                core_schema.no_info_plain_validator_function(validate_lax)
            ]),
            strict_schema=core_schema.none_schema(),  # Always fails in strict mode
        )


class UnrecognizedInt(int):
    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type: Any, _handler: Any) -> core_schema.CoreSchema:
        # Make UnrecognizedInt only work in lax mode, not strict mode
        # This makes it a "fallback" option when more specific types (like Literals) don't match
        def validate_lax(v: Any) -> 'UnrecognizedInt':
            if isinstance(v, cls):
                return v
            return cls(int(v))
        return core_schema.lax_or_strict_schema(
            lax_schema=core_schema.chain_schema([
                core_schema.int_schema(),
                core_schema.no_info_plain_validator_function(validate_lax)
            ]),
            strict_schema=core_schema.none_schema(),  # Always fails in strict mode
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class Category(str, Enum):
    r"""Event category."""

    APPSEC_DAYS = "appsec_days"
    GLOBAL = "global"
    OTHER = "other"
    PARTNER = "partner"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class MemberType(str, Enum):
    r"""Member type choices."""

    PLATINUM = "Platinum"
    GOLD = "Gold"
    SILVER = "Silver"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .membertype import MemberType
from enum import Enum
from owasp_nest.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from owasp_nest.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListSponsorsOrdering(str, Enum):
    r"""Ordering field"""

    NAME = "name"
    MINUS_NAME = "-name"


class ListSponsorsRequestTypedDict(TypedDict):
    is_member: NotRequired[Nullable[bool]]
    r"""Member status of the sponsor"""
    member_type: NotRequired[Nullable[MemberType]]
    r"""Member type of the sponsor"""
    sponsor_type: NotRequired[Nullable[str]]
    r"""Filter by the type of sponsorship (e.g., Gold, Silver, Platinum)."""
    ordering: NotRequired[Nullable[ListSponsorsOrdering]]
    r"""Ordering field"""
    page: NotRequired[int]
    r"""Page number"""
    page_size: NotRequired[int]
    r"""Number of items per page"""


class ListSponsorsRequest(BaseModel):
    is_member: Annotated[
        OptionalNullable[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Member status of the sponsor"""

    member_type: Annotated[
        OptionalNullable[MemberType],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Member type of the sponsor"""

    sponsor_type: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by the type of sponsorship (e.g., Gold, Silver, Platinum)."""

    ordering: Annotated[
        OptionalNullable[ListSponsorsOrdering],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Ordering field"""

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""Number of items per page"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "is_member",
                "member_type",
                "sponsor_type",
                "ordering",
                "page",
                "page_size",
            ]
        )
        nullable_fields = set(["is_member", "member_type", "sponsor_type", "ordering"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from owasp_nest.models import NestError
from owasp_nest.types import BaseModel, OptionalNullable, UNSET
from typing import Any, Dict, List, Optional, Union
from typing_extensions import TypeAliasType


ErrorsTypedDict = TypeAliasType(
    "ErrorsTypedDict", Union[List[Dict[str, Any]], Dict[str, Any]]
)


Errors = TypeAliasType("Errors", Union[List[Dict[str, Any]], Dict[str, Any]])


class ValidationErrorSchemaData(BaseModel):
    message: str
    errors: OptionalNullable[Errors] = UNSET


@dataclass(unsafe_hash=True)
class ValidationErrorSchema(NestError):
    r"""Schema for validation error."""

    data: ValidationErrorSchemaData = field(hash=False)

    def __init__(
        self,
        data: ValidationErrorSchemaData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class RepositoryTypedDict(TypedDict):
    r"""Schema for Repository (minimal fields for list display)."""

    created_at: datetime
    name: str
    updated_at: datetime


class Repository(BaseModel):
    r"""Schema for Repository (minimal fields for list display)."""

    created_at: datetime

    name: str

    updated_at: datetime
